@@ -10,10 +10,9 @@
 #include "settings.h"
 #include "undo.h"
 // KDEGames
-#include <kdegames_version.h>
 #include <KGamePopupItem>
-#include <KgTheme>
-#include <KgThemeProvider>
+#include <KGameTheme>
+#include <KGameThemeProvider>
 // KF
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -27,18 +26,14 @@
 #include <QSequentialAnimationGroup>
 #include <QStandardPaths>
 
-static KgThemeProvider* provider()
+static KGameThemeProvider* provider()
 {
     //TODO: Do we want to store separate theme choices for Klickety and KSame?
     const QLatin1String defaultTheme =
         Settings::self()->config()->name() == QLatin1String("ksamerc")
         ? QLatin1String("ksame") : QLatin1String("default");
-    KgThemeProvider* prov = new KgThemeProvider;
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    KGameThemeProvider* prov = new KGameThemeProvider;
     prov->discoverThemes(QStringLiteral("themes"), defaultTheme);
-#else
-    prov->discoverThemes("appdata", QStringLiteral("themes"), defaultTheme);
-#endif
     return prov;
 }
 
@@ -277,7 +272,7 @@ bool GameScene::isGameFinished() const
     return true;
 }
 
-KgThemeProvider* GameScene::themeProvider() const
+KGameThemeProvider* GameScene::themeProvider() const
 {
     return m_renderer.themeProvider();
 }
